package com.tourism.webadmin.app.website.controller;

import cn.dev33.satoken.annotation.SaIgnore;
import com.tourism.common.additional.model.FileUrlObject;
import com.tourism.common.additional.utils.JsonUtils;
import com.tourism.common.additional.utils.StringUtils;
import com.tourism.common.core.object.MyOrderParam;
import com.tourism.common.core.object.MyPageData;
import com.tourism.common.core.object.ResponseResult;
import com.tourism.common.core.util.MyPageUtil;
import com.tourism.common.log.annotation.OperationLog;
import com.tourism.common.log.model.constant.SysOperationLogType;
import com.tourism.webadmin.back.model.BannerInfo;
import com.tourism.webadmin.back.model.CompanyInfo;
import com.tourism.webadmin.back.model.DirectoryInfo;
import com.tourism.webadmin.back.service.BannerInfoService;
import com.tourism.webadmin.back.service.CompanyInfoService;
import com.tourism.webadmin.back.service.DirectoryInfoService;
import com.tourism.webadmin.back.vo.BannerInfoVo;
import com.tourism.webadmin.back.vo.CompanyInfoVo;
import com.tourism.webadmin.back.vo.DirectoryInfoVo;
import com.tourism.webadmin.config.ApplicationDevConfig;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.constraints.NotNull;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.util.CollectionUtils;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.List;

@Tag(name = "门户网站基础信息接口")
@Slf4j
@RestController
@SaIgnore
@Validated
@ConditionalOnProperty(name = "common-online.operationEnabled", havingValue = "true")
@RequestMapping("/website/basic")
public class BasicToWebController {

    @Autowired
    private BannerInfoService bannerInfoService;
    @Autowired
    private CompanyInfoService companyInfoService;
    @Autowired
    private DirectoryInfoService directoryInfoService;
    @Autowired
    private ApplicationDevConfig applicationDevConfig;

    /**
     * 列出符合过滤条件的banner管理列表。
     * @return 应答结果对象，包含查询结果集。
     */
    @OperationLog(type = SysOperationLogType.ADD)
    @GetMapping("/bannerList")
    public ResponseResult<MyPageData<BannerInfoVo>> bannerInfoList(@NotNull(message = "所属分类(belongTab)不能为空") Long belongTab) {
        BannerInfo bannerInfoFilter = new BannerInfo();
        bannerInfoFilter.setBelongTab(belongTab);
        //首页展示的话，只能展示启用的banner图
        bannerInfoFilter.setEnable(1);
        String orderBy = MyOrderParam.buildOrderBy(new MyOrderParam(), BannerInfo.class);
        List<BannerInfo> bannerInfoList = bannerInfoService.getBannerInfoListWithRelation(bannerInfoFilter, orderBy);
        MyPageData<BannerInfoVo> bannerInfoVoMyPageData = MyPageUtil.makeResponseData(bannerInfoList, BannerInfoVo.class);

        List<BannerInfoVo> dataList = bannerInfoVoMyPageData.getDataList();
        //先把imgUrl由jaon转换为List<FileUrlObject>
        dataList.stream().forEach(item ->
        {
            if (StringUtils.isNotEmpty(item.getImgUrl())) {
                List<FileUrlObject> fileUrlObjectList = JsonUtils.parseFileUrlArray(item.getImgUrl(), FileUrlObject.class);
                if (!CollectionUtils.isEmpty(fileUrlObjectList)) {
                    ArrayList<String> arrayList = new ArrayList<>();
                    //遍历每个元素的数组对象,对元素的url对象进行拼接
                    for (FileUrlObject y : fileUrlObjectList) {
                        String imgUrlAfterConvert =
                                applicationDevConfig.getHostIpPort() + y.getDownloadUri() + "?id=" + item.getId() + "&fieldName=imgUrl&asImage=true&filename=" + y.getFilename();
                        arrayList.add(imgUrlAfterConvert);
                    }
                    item.setImgUrlsAfterConvert(arrayList);
                }
            }
        });
        return ResponseResult.success(bannerInfoVoMyPageData);
    }

    /**
     * 列出符合过滤条件的门户菜单管理列表。
     * @return 应答结果对象，包含查询结果集。
     */
    @GetMapping("/directoryList")
    public ResponseResult<MyPageData<DirectoryInfoVo>> directoryInfoList(Long parentId,Integer isHotspot) {
//        if (ObjectUtils.isEmpty(parentId)){
//            return ResponseResult.error("NO-ERROR","父级Id为空");
//        }
        DirectoryInfo directoryInfoFilter = new DirectoryInfo();
        if(parentId != null){
            directoryInfoFilter.setParentId(parentId);
        }
        if(isHotspot != null){
            directoryInfoFilter.setIsHotspot(isHotspot);
        }
        String orderBy = MyOrderParam.buildOrderBy(new MyOrderParam(), DirectoryInfo.class);
        List<DirectoryInfo> directoryInfoList =
                directoryInfoService.getDirectoryInfoListWithRelation(directoryInfoFilter, orderBy);

        MyPageData<DirectoryInfoVo> directoryInfoVoMyPageData = MyPageUtil.makeResponseData(directoryInfoList, DirectoryInfoVo.class);

        List<DirectoryInfoVo> dataList = directoryInfoVoMyPageData.getDataList();
        //先把imgUrl由jaon转换为List<FileUrlObject>
        dataList.stream().forEach(item ->
        {
            if (StringUtils.isNotEmpty(item.getHotPictureUrl())) {
                List<FileUrlObject> fileUrlObjectList = JsonUtils.parseFileUrlArray(item.getHotPictureUrl(), FileUrlObject.class);
                if (!CollectionUtils.isEmpty(fileUrlObjectList)) {
                    ArrayList<String> arrayList = new ArrayList<>();
                    //遍历每个元素的数组对象,对元素的url对象进行拼接
                    for (FileUrlObject y : fileUrlObjectList) {
                        String hotPictureUrlsAfterConvert =
                                applicationDevConfig.getHostIpPort() + y.getDownloadUri() + "?id=" + item.getId() + "&fieldName=hotPictureUrl&asImage=true&filename=" + y.getFilename();
                        arrayList.add(hotPictureUrlsAfterConvert);
                    }
                    item.setHotPictureUrlsAfterConvert(arrayList);
                }
            }
        });

        return ResponseResult.success(directoryInfoVoMyPageData);
    }

//    /**
//     * 列出符合过滤条件的公司信息管理列表。
//     *  @return 应答结果对象，包含查询结果集。
//     */
//    @GetMapping("/companyList")
//    public ResponseResult<MyPageData<CompanyInfoVo>> companyInfoList(@NotNull(message = "公司类型(companyType)不能为空") Integer companyType) {
//        CompanyInfo companyInfoFilter = new CompanyInfo();
//        companyInfoFilter.setCompanyType(companyType);
//        String orderBy = MyOrderParam.buildOrderBy(new MyOrderParam(), CompanyInfo.class);
//        List<CompanyInfo> companyInfoList =
//                companyInfoService.getCompanyInfoListWithRelation(companyInfoFilter, orderBy);
//        return ResponseResult.success(MyPageUtil.makeResponseData(companyInfoList, CompanyInfoVo.class));
//    }
}
